consistencydetector

package
v0.35.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 17, 2025 License: Apache-2.0 Imports: 13 Imported by: 3

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CheckDataConsistency

func CheckDataConsistency[T runtime.Object, U any](ctx context.Context, identity string, lastSyncedResourceVersion string, listFn ListFunc[T], listItemTransformFunc TransformFunc, listOptions metav1.ListOptions, retrieveItemsFn RetrieveItemsFunc[U])

CheckDataConsistency exists solely for testing purposes. we cannot use checkWatchListDataConsistencyIfRequested because it is guarded by an environmental variable. we cannot manipulate the environmental variable because it will affect other tests in this package.

func IsDataConsistencyDetectionForWatchListEnabled

func IsDataConsistencyDetectionForWatchListEnabled() bool

IsDataConsistencyDetectionForWatchListEnabled returns true when the KUBE_WATCHLIST_INCONSISTENCY_DETECTOR environment variable was set during a binary startup.

func SetDataConsistencyDetectionForWatchListEnabledForTest added in v0.34.3

func SetDataConsistencyDetectionForWatchListEnabledForTest(enabled bool) func()

SetDataConsistencyDetectionForWatchListEnabledForTest allows to enable/disable data consistency detection for testing purposes. It returns a function that restores the original value.

Types

type ListFunc

type ListFunc[T runtime.Object] func(ctx context.Context, options metav1.ListOptions) (T, error)

type RetrieveItemsFunc

type RetrieveItemsFunc[U any] func() []U

type TransformFunc added in v0.34.3

type TransformFunc func(interface{}) (interface{}, error)

Jump to