client-gok8s.io/client-go/util/consistencydetector Index | Files

package consistencydetector

import "k8s.io/client-go/util/consistencydetector"

Index

Functions

func CheckDataConsistency

func CheckDataConsistency[T runtime.Object, U any](ctx context.Context, identity string, lastSyncedResourceVersion string, listFn ListFunc[T], listOptions metav1.ListOptions, retrieveItemsFn RetrieveItemsFunc[U])

CheckDataConsistency exists solely for testing purposes. we cannot use checkWatchListDataConsistencyIfRequested because it is guarded by an environmental variable. we cannot manipulate the environmental variable because it will affect other tests in this package.

func IsDataConsistencyDetectionForWatchListEnabled

func IsDataConsistencyDetectionForWatchListEnabled() bool

IsDataConsistencyDetectionForWatchListEnabled returns true when the KUBE_WATCHLIST_INCONSISTENCY_DETECTOR environment variable was set during a binary startup.

Types

type ListFunc

type ListFunc[T runtime.Object] func(ctx context.Context, options metav1.ListOptions) (T, error)

type RetrieveItemsFunc

type RetrieveItemsFunc[U any] func() []U

Source Files

data_consistency_detector.go

Version
v0.35.0-beta.0
Published
Nov 19, 2025
Platform
linux/amd64
Imports
13 packages
Last checked
1 hour ago

Tools for package owners.