package consistencydetector
import "k8s.io/client-go/util/consistencydetector"
Index ¶
- func CheckDataConsistency[T runtime.Object, U any](ctx context.Context, identity string, lastSyncedResourceVersion string, listFn ListFunc[T], listOptions metav1.ListOptions, retrieveItemsFn RetrieveItemsFunc[U])
- func IsDataConsistencyDetectionForWatchListEnabled() bool
- type ListFunc
- type RetrieveItemsFunc
Functions ¶
func CheckDataConsistency ¶
func CheckDataConsistency[T runtime.Object, U any](ctx context.Context, identity string, lastSyncedResourceVersion string, listFn ListFunc[T], listOptions metav1.ListOptions, retrieveItemsFn RetrieveItemsFunc[U])
CheckDataConsistency exists solely for testing purposes. we cannot use checkWatchListDataConsistencyIfRequested because it is guarded by an environmental variable. we cannot manipulate the environmental variable because it will affect other tests in this package.
func IsDataConsistencyDetectionForWatchListEnabled ¶
func IsDataConsistencyDetectionForWatchListEnabled() bool
IsDataConsistencyDetectionForWatchListEnabled returns true when the KUBE_WATCHLIST_INCONSISTENCY_DETECTOR environment variable was set during a binary startup.
Types ¶
type ListFunc ¶
type RetrieveItemsFunc ¶
type RetrieveItemsFunc[U any] func() []U
Source Files ¶
data_consistency_detector.go
- Version
- v0.35.0-alpha.2
- Published
- Oct 22, 2025
- Platform
- linux/amd64
- Imports
- 13 packages
- Last checked
- 34 minutes ago –
Tools for package owners.